==> spip_3.2.11.orig.tar.xz: plugins-dist/dump/lang/dump_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=cpf
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Rosarz léta labazwèb',

	// I
	'info_restauration_sauvegarde' => 'rosarz léta lasovgard @archive@', # MODIF
	'info_sauvegarde' => 'Sovgard',
	'info_sauvegarde_reussi_02' => 'Labazdodné la finn dèt sovgardé dann @archive@. Ou pé',
	'info_sauvegarde_reussi_03' => 'Artourn si lo kolonaz',
	'info_sauvegarde_reussi_04' => 'out sitwèb.',

	// T
	'texte_admin_tech_01' => 'Lopsyon-la li rand aou kav sovgard lo kontnu
la bazdodné. Pou sa minm, oubli pa mèt ali andann  fisyé prési dann répèrtwar   @dossier@.
Oubli pa rékupèr osi tout sak nana dann répertwar <i>IMG/</i>, sé dir
tout bann zimaz èk tout bann dokiman knéna dann bann zartik èk bann rubrik.',
	'texte_admin_tech_02' => 'Tansyon pangar : sovgard-la li sra posib réstoré 
SÈLMAN sir inn sitwèb ki néna inn minm versyon do SPIP. Pangar sirtou pa  « dégrené labaz-la »  èk lidé install in in sovgar apré larnouvèlman.Pour plid détay anon vwar isi lapaz <a href="@spipnet@">la documentation de SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Rosarz lo kontnu lasovgard labaz',
	'texte_restaurer_sauvegarde' => 'Lopsyon-la i permé rosarz inn sovgard sak ou néna déza fé sir labaz. Pour sa, ifo mèt lo fisyé la sovgard dann répertwar@dossier@.
Inn ti péd prékosyon lé nésésèr èk lafonksyon-la : porézon <b>bann sanzman ou bann pèrt sak ou pé konèt, zot i pé pa bataryèr.</b>', # MODIF
	'texte_sauvegarde' => 'Sovgard lo kontnu labaz',
	'texte_sauvegarde_base' => 'Sovgard labaz dodné'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_cpf.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=cpf
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Rosarz léta labazwèb',

	// I
	'info_restauration_sauvegarde' => 'rosarz léta lasovgard @archive@', # MODIF
	'info_sauvegarde' => 'Sovgard',
	'info_sauvegarde_reussi_02' => 'Labazdodné la finn dèt sovgardé dann @archive@. Ou pé',
	'info_sauvegarde_reussi_03' => 'Artourn si lo kolonaz',
	'info_sauvegarde_reussi_04' => 'out sitwèb.',

	// T
	'texte_admin_tech_01' => 'Lopsyon-la li rand aou kav sovgard lo kontnu
la bazdodné. Pou sa minm, oubli pa mèt ali andann  fisyé prési dann répèrtwar   @dossier@.
Oubli pa rékupèr osi tout sak nana dann répertwar <i>IMG/</i>, sé dir
tout bann zimaz èk tout bann dokiman knéna dann bann zartik èk bann rubrik.',
	'texte_admin_tech_02' => 'Tansyon pangar : sovgard-la li sra posib réstoré 
SÈLMAN sir inn sitwèb ki néna inn minm versyon do SPIP. Pangar sirtou pa  « dégrené labaz-la »  èk lidé install in in sovgar apré larnouvèlman.Pour plid détay anon vwar isi lapaz <a href="@spipnet@">la documentation de SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Rosarz lo kontnu lasovgard labaz',
	'texte_restaurer_sauvegarde' => 'Lopsyon-la i permé rosarz inn sovgard sak ou néna déza fé sir labaz. Pour sa, ifo mèt lo fisyé la sovgard dann répertwar@dossier@.
Inn ti péd prékosyon lé nésésèr èk lafonksyon-la : porézon <b>bann sanzman ou bann pèrt sak ou pé konèt, zot i pé pa bataryèr.</b>', # MODIF
	'texte_sauvegarde' => 'Sovgard lo kontnu labaz',
	'texte_sauvegarde_base' => 'Sovgard labaz dodné',
];
